@@ -1,7 +1,7 @@
 /*
  * Shared test functions for libCACard
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright 2018 - 2022 Red Hat, Inc.
  *
  * Author: Jakub Jelen <jjelen@redhat.com>
  *
@@ -98,7 +98,7 @@ void select_aid(VReader *reader, unsigned char *aid, unsigned int aid_len)
 }
 
 void get_properties_coid(VReader *reader, const unsigned char coid[2],
-                         int object_type)
+                         enum TestObjectType object_type)
 {
     int dwRecvLength = APDUBufSize;
     VReaderStatus status;
@@ -192,7 +192,7 @@ void get_properties_coid(VReader *reader, const unsigned char coid[2],
 
                 case 0x43: /* PKI properties */
                     g_assert_cmphex(p2[0], ==, 0x06);
-                    if (hw_tests) {
+                    if (hw_tests && object_type == TEST_PKI) {
                         /* Assuming CAC card with 1024 b RSA keys */
                         key_bits = 1024;
                     } else {
@@ -248,7 +248,7 @@ void get_properties_coid(VReader *reader, const unsigned char coid[2],
         g_assert_cmpint(num_objects_expected, ==, 0);
     }
 
-    if (object_type == TEST_PKI) {
+    if (object_type == TEST_PKI || object_type == TEST_PKI_2) {
         g_assert_cmpint(verified_pki_properties, ==, 1);
     }
 
@@ -302,17 +302,22 @@ void get_properties_coid(VReader *reader, const unsigned char coid[2],
 
 }
 
-void get_properties(VReader *reader, int object_type)
+void get_properties(VReader *reader, enum TestObjectType object_type)
 {
     unsigned char coid[2];
     switch (object_type) {
     case TEST_PKI:
-        // XXX only the first PKI for now
         coid[0] = 0x01;
         coid[1] = 0x00;
         get_properties_coid(reader, coid, object_type);
         break;
 
+    case TEST_PKI_2:
+        coid[0] = 0x01;
+        coid[1] = 0x01;
+        get_properties_coid(reader, coid, object_type);
+        break;
+
     case TEST_CCC:
         coid[0] = 0xDB;
         coid[1] = 0x00;
@@ -325,13 +330,17 @@ void get_properties(VReader *reader, int object_type)
         get_properties_coid(reader, coid, object_type);
         break;
 
+    case TEST_GENERIC:
+    case TEST_EMPTY_BUFFER:
+    case TEST_EMPTY:
+    case TEST_PASSTHROUGH:
     default:
         g_debug("Got unknown object type");
         g_assert_not_reached();
     }
 }
 
-void read_buffer(VReader *reader, uint8_t type, int object_type)
+void read_buffer(VReader *reader, uint8_t type, enum TestObjectType object_type)
 {
     int dwRecvLength = APDUBufSize, dwLength, dwReadLength, offset, left;
     VReaderStatus status;
@@ -412,7 +421,7 @@ void read_buffer(VReader *reader, uint8_t type, int object_type)
     g_free(data);
 }
 
-void select_applet(VReader *reader, int type)
+void select_applet(VReader *reader, enum TestObjectType type)
 {
     uint8_t selfile_ccc[] = {
         /* Select CCC Applet */
@@ -426,6 +435,10 @@ void select_applet(VReader *reader, int type)
         /* Select first PKI Applet */
         0xa0, 0x00, 0x00, 0x00, 0x79, 0x01, 0x00
     };
+    uint8_t selfile_pki_2[] = {
+        /* Select second PKI Applet */
+        0xa0, 0x00, 0x00, 0x00, 0x79, 0x01, 0x01
+    };
     uint8_t selfile_passthrough[] = {
         /* Select Person Instance (passthrough) */
         0xa0, 0x00, 0x00, 0x00, 0x79, 0x02, 0x00
@@ -442,6 +455,11 @@ void select_applet(VReader *reader, int type)
         aid_len = sizeof(selfile_pki);
         break;
 
+    case TEST_PKI_2:
+        aid = selfile_pki_2;
+        aid_len = sizeof(selfile_pki_2);
+        break;
+
     case TEST_CCC:
         aid = selfile_ccc;
         aid_len = sizeof(selfile_ccc);
@@ -462,6 +480,8 @@ void select_applet(VReader *reader, int type)
         aid_len = sizeof(selfile_empty);
         break;
 
+    case TEST_GENERIC:
+    case TEST_EMPTY_BUFFER:
     default:
         g_assert_not_reached();
     }
@@ -562,7 +582,7 @@ void do_sign(VReader *reader, int parts)
 
 }
 
-void do_decipher(VReader *reader)
+void do_decipher(VReader *reader, enum TestObjectType type)
 {
     VReaderStatus status;
     int dwRecvLength = APDUBufSize;
@@ -589,14 +609,30 @@ void do_decipher(VReader *reader)
 
     /* Read the encrypted file */
     if (hw_tests) {
-        filename = g_test_build_filename(G_TEST_BUILT, "01.crypt", NULL);
+        const char *name;
+        if (type == TEST_PKI) {
+            name = "01.crypt";
+        } else if (type == TEST_PKI_2) {
+            name = "02.crypt";
+        } else {
+            g_assert_not_reached();
+        }
+        filename = g_test_build_filename(G_TEST_BUILT, name, NULL);
     } else {
         /* Generated from existing db using:
          * echo "1234567890" > data
          * certutil -L -d sql:$PWD/tests/db/ -n cert1 -r > tests/db.cert
          * openssl rsautl -encrypt -inkey "tests/db.cert" -keyform DER -certin -in data -out "tests/db.crypt"
          */
-        filename = g_test_build_filename(G_TEST_DIST, "db.crypt", NULL);
+        const char *name;
+        if (type == TEST_PKI) {
+            name = "db.crypt";
+        } else if (type == TEST_PKI_2) {
+            name = "db2.crypt";
+        } else {
+            g_assert_not_reached();
+        }
+        filename = g_test_build_filename(G_TEST_DIST, name, NULL);
     }
     if (!g_file_get_contents(filename, &ciphertext, &ciphertext_len, NULL)) {
         g_test_skip("The encrypted file not found");
@@ -944,7 +980,21 @@ void test_msft_applet(void)
      * in select_aid()
      */
 
+    /* ask the applet for unknown data */
+    getdata[2] = 0xff;
+    getdata[3] = 0xff;
+    dwRecvLength = APDUBufSize;
+    status = vreader_xfr_bytes(reader,
+                               getdata, sizeof(getdata),
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[dwRecvLength-2], ==, 0x6a);
+    g_assert_cmpint(pbRecvBuffer[dwRecvLength-1], ==, 0x88);
+
     /* ask the applet for our data */
+    getdata[2] = 0x7f;
+    getdata[3] = 0x68;
     dwRecvLength = APDUBufSize;
     status = vreader_xfr_bytes(reader,
                                getdata, sizeof(getdata),
@@ -973,24 +1023,18 @@ void test_msft_applet(void)
     vreader_free(reader); /* get by id ref */
 }
 
-void test_gp_applet(void)
+void select_gp(VReader *reader)
 {
     int dwRecvLength = APDUBufSize;
     VReaderStatus status;
     uint8_t pbRecvBuffer[APDUBufSize];
-    uint8_t gp_aid[] = {
-        0xA0, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00
-    };
     uint8_t getresp[] = {
         /* Get Response (max we can get) */
         0x00, 0xc0, 0x00, 0x00, 0x00
     };
-    uint8_t getdata[] = {
-        /* Get Data (max we can get) */
-        0x00, 0xca, 0x9f, 0x7f, 0x00
+    uint8_t gp_aid[] = {
+        0xA0, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00
     };
-    VReader *reader = vreader_get_reader_by_id(0);
-    unsigned int equal_bytes = 0, n;
 
     /* select GP and wait for the response bytes */
     select_aid_response(reader, gp_aid, sizeof(gp_aid), 0x1b);
@@ -1004,6 +1048,21 @@ void test_gp_applet(void)
     g_assert_cmpint(dwRecvLength, >, 2);
     g_assert_cmphex(pbRecvBuffer[dwRecvLength-2], ==, VCARD7816_SW1_SUCCESS);
     g_assert_cmphex(pbRecvBuffer[dwRecvLength-1], ==, 0x00);
+}
+
+void test_gp_applet(void)
+{
+    int dwRecvLength = APDUBufSize;
+    VReaderStatus status;
+    uint8_t pbRecvBuffer[APDUBufSize];
+    uint8_t getdata[] = {
+        /* Get Data (max we can get) */
+        0x00, 0xca, 0x9f, 0x7f, 0x00
+    };
+    VReader *reader = vreader_get_reader_by_id(0);
+    unsigned int equal_bytes = 0, n;
+
+    select_gp(reader);
 
     /* We made sure the selection of other applets does not return anything
      * in select_aid()
@@ -1025,6 +1084,29 @@ void test_gp_applet(void)
     }
     g_assert_cmpint(equal_bytes, <, 6);
 
+    /* 0x0066 tag should return card registration data */
+    dwRecvLength = APDUBufSize;
+    getdata[2] = 0x00;
+    getdata[3] = 0x66;
+    status = vreader_xfr_bytes(reader,
+                               getdata, sizeof(getdata),
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 53);
+    g_assert_cmpint(pbRecvBuffer[dwRecvLength-2], ==, VCARD7816_SW1_SUCCESS);
+    g_assert_cmpint(pbRecvBuffer[dwRecvLength-1], ==, 0x00);
+
+    /* anything else should fail */
+    dwRecvLength = APDUBufSize;
+    getdata[2] = 0xff;
+    getdata[3] = 0xff;
+    status = vreader_xfr_bytes(reader,
+                               getdata, sizeof(getdata),
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[dwRecvLength-2], ==, 0x6a);
+    g_assert_cmpint(pbRecvBuffer[dwRecvLength-1], ==, 0x88);
     vreader_free(reader); /* get by id ref */
 }
 
