@@ -1,7 +1,7 @@
 /*
  * Shared test functions for libCACard
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright 2018 - 2022 Red Hat, Inc.
  *
  * Author: Jakub Jelen <jjelen@redhat.com>
  *
@@ -15,14 +15,15 @@
 
 #define APDUBufSize 270
 
-enum {
+enum TestObjectType {
     TEST_PKI = 1,
-    TEST_CCC = 2,
-    TEST_ACA = 3,
-    TEST_GENERIC = 4,
-    TEST_EMPTY_BUFFER = 5,
-    TEST_EMPTY = 6,
-    TEST_PASSTHROUGH = 7,
+    TEST_PKI_2,
+    TEST_CCC,
+    TEST_ACA,
+    TEST_GENERIC,
+    TEST_EMPTY_BUFFER,
+    TEST_EMPTY,
+    TEST_PASSTHROUGH,
 };
 
 void select_coid_good(VReader *reader, unsigned char *coid);
@@ -31,16 +32,16 @@ void select_coid_bad(VReader *reader, unsigned char *coid);
 int select_aid_response(VReader *reader, unsigned char *aid,
                         unsigned int aid_len, int response);
 void select_aid(VReader *reader, unsigned char *aid, unsigned int aid_len);
-void select_applet(VReader *reader, int type);
+void select_applet(VReader *reader, enum TestObjectType type);
 
-void get_properties_coid(VReader *reader, const unsigned char coid[2], int object_type);
-void get_properties(VReader *reader, int object_type);
+void get_properties_coid(VReader *reader, const unsigned char coid[2], enum TestObjectType object_type);
+void get_properties(VReader *reader, enum TestObjectType object_type);
 
-void read_buffer(VReader *reader, uint8_t type, int object_type);
+void read_buffer(VReader *reader, uint8_t type, enum TestObjectType object_type);
 
 void do_sign(VReader *reader, int parts);
 
-void do_decipher(VReader *reader);
+void do_decipher(VReader *reader, enum TestObjectType object_type);
 
 void test_empty_applets(void);
 
@@ -48,6 +49,8 @@ void test_get_response(void);
 
 void check_login_count(void);
 
+void select_gp(VReader *reader);
+
 void test_msft_applet(void);
 void test_gp_applet(void);
 
