@@ -1,7 +1,7 @@
 /*
  * Test general functionality of software emulated smart card
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright 2018 - 2022 Red Hat, Inc.
  *
  * Authors:
  *  Marc-André Lureau <marcandre.lureau@redhat.com>
@@ -515,6 +515,25 @@ static void test_cac_pki(void)
     vreader_free(reader); /* get by id ref */
 }
 
+static void test_cac_pki_2(void)
+{
+    VReader *reader = vreader_get_reader_by_id(0);
+
+    /* select the first PKI applet */
+    select_applet(reader, TEST_PKI_2);
+
+    /* get properties */
+    get_properties(reader, TEST_PKI_2);
+
+    /* get the TAG buffer length */
+    read_buffer(reader, CAC_FILE_TAG, TEST_PKI_2);
+
+    /* get the VALUE buffer length */
+    read_buffer(reader, CAC_FILE_VALUE, TEST_PKI_2);
+
+    vreader_free(reader); /* get by id ref */
+}
+
 static void test_cac_ccc(void)
 {
     VReader *reader = vreader_get_reader_by_id(0);
@@ -579,6 +598,14 @@ static void test_sign(void)
     /* test also multipart signatures */
     do_sign(reader, 1);
 
+    /* select the second PKI */
+    select_applet(reader, TEST_PKI_2);
+
+    do_sign(reader, 0);
+
+    /* test also multipart signatures */
+    do_sign(reader, 1);
+
     vreader_free(reader); /* get by id ref */
 }
 
@@ -594,7 +621,12 @@ static void test_decipher(void)
     /* select the PKI */
     select_applet(reader, TEST_PKI);
 
-    do_decipher(reader);
+    do_decipher(reader, TEST_PKI);
+
+    /* select the PKI */
+    select_applet(reader, TEST_PKI_2);
+
+    do_decipher(reader, TEST_PKI_2);
 
     vreader_free(reader); /* get by id ref */
 }
@@ -654,6 +686,31 @@ static void test_select_coid(void)
     vreader_free(reader); /* get by id ref */
 }
 
+static void test_invalid_apdu(void)
+{
+    VReader *reader = vreader_get_reader_by_id(0);
+    VReaderStatus status;
+    int dwRecvLength = APDUBufSize;
+    uint8_t pbRecvBuffer[APDUBufSize];
+    uint8_t apdu[] = {
+        0x00, 0x00, 0x01
+    };
+    size_t apdu_len = 3;
+
+    g_assert_nonnull(reader);
+
+    dwRecvLength = APDUBufSize;
+    status = vreader_xfr_bytes(reader,
+                               apdu, apdu_len,
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[0], ==, 0x67);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x00);
+
+    vreader_free(reader); /* get by id ref */
+}
+
 static void test_invalid_properties(void)
 {
     VReader *reader = vreader_get_reader_by_id(0);
@@ -781,6 +838,19 @@ static void test_invalid_select(void)
     g_assert_cmpint(pbRecvBuffer[0], ==, VCARD7816_SW1_COMMAND_ERROR);
     g_assert_cmpint(pbRecvBuffer[1], ==, 0x84);
 
+    /* The generic code handles only P1 = 0x04 */
+    select_gp(reader);
+
+    selfile[2] = 0xff;
+    dwRecvLength = APDUBufSize;
+    status = vreader_xfr_bytes(reader,
+                               selfile, sizeof(selfile),
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[0], ==, 0x6a);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x81);
+
     /* TODO check the iso7816 code handling the remaining SELECT APDUs */
 
     vreader_free(reader); /* get by id ref */
@@ -801,15 +871,15 @@ static void test_invalid_instruction(void)
     /* Card Capability Container */
     select_applet(reader, TEST_CCC);
 
-    /* 0xFF is invalid instruction everywhere, but fails in apdu_ins_to_string() */
-    /*dwRecvLength = APDUBufSize;
+    /* 0xFF is invalid instruction everywhere */
+    dwRecvLength = APDUBufSize;
     status = vreader_xfr_bytes(reader,
                                apdu, sizeof(apdu),
                                pbRecvBuffer, &dwRecvLength);
     g_assert_cmpint(status, ==, VREADER_OK);
     g_assert_cmpint(dwRecvLength, ==, 2);
     g_assert_cmpint(pbRecvBuffer[0], ==, VCARD7816_SW1_INS_ERROR);
-    g_assert_cmpint(pbRecvBuffer[1], ==, 0x00);*/
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x00);
 
     /* CCC Applet does not know GET ACR instruction */
     apdu[1] = 0x4c;
@@ -824,12 +894,11 @@ static void test_invalid_instruction(void)
 
     /* TODO check the iso7816 code handling the remaining SELECT APDUs */
 
+    /* GP applet sends most of the instructions to the generic ISO handling */
+    select_gp(reader);
 
-    /* PKI Applet */
-    select_applet(reader, TEST_PKI);
-
-    /* Update Buffer is not supported */
-    apdu[1] = 0x58;
+    /* Secure messaging instructions not supported */
+    apdu[1] = 0x70;
     dwRecvLength = APDUBufSize;
     status = vreader_xfr_bytes(reader,
                                apdu, sizeof(apdu),
@@ -837,12 +906,22 @@ static void test_invalid_instruction(void)
     g_assert_cmpint(status, ==, VREADER_OK);
     g_assert_cmpint(dwRecvLength, ==, 2);
     g_assert_cmpint(pbRecvBuffer[0], ==, VCARD7816_SW1_COMMAND_ERROR);
-    g_assert_cmpint(pbRecvBuffer[1], ==, 0x85);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x00);
 
+    /* 0xFF is invalid instruction also in the global APDU processing */
+    apdu[1] = 0xff;
+    dwRecvLength = APDUBufSize;
+    status = vreader_xfr_bytes(reader,
+                               apdu, sizeof(apdu),
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[0], ==, 0x69);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x00);
     vreader_free(reader); /* get by id ref */
 }
 
-static void test_invalid_read_buffer_applet(VReader *reader, int object_type)
+static void test_invalid_read_buffer_applet(VReader *reader, enum TestObjectType object_type)
 {
 
     VReaderStatus status;
@@ -925,12 +1004,145 @@ static void test_invalid_read_buffer(void)
 
     test_invalid_read_buffer_applet(reader, TEST_CCC);
     test_invalid_read_buffer_applet(reader, TEST_PKI);
+    test_invalid_read_buffer_applet(reader, TEST_PKI_2);
     test_invalid_read_buffer_applet(reader, TEST_PASSTHROUGH);
     test_invalid_read_buffer_applet(reader, TEST_EMPTY);
 
     vreader_free(reader); /* get by id ref */
 }
 
+static void test_invalid_update_buffer_applet(VReader *reader, enum TestObjectType object_type)
+{
+
+    VReaderStatus status;
+    int dwRecvLength = APDUBufSize;
+    uint8_t pbRecvBuffer[APDUBufSize];
+    uint8_t apdu[] = {
+        0x00, 0x58, 0x00, 0x00, 0x00
+    };
+    int apdu_len = 5;
+
+    select_applet(reader, object_type);
+
+    /* Update buffer is not supported */
+    status = vreader_xfr_bytes(reader,
+                               apdu, apdu_len,
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    if (object_type == TEST_PKI || object_type == TEST_PKI_2) {
+        g_assert_cmpint(pbRecvBuffer[0], ==, 0x69);
+        g_assert_cmpint(pbRecvBuffer[1], ==, 0x85);
+    } else {
+        g_assert_cmpint(pbRecvBuffer[0], ==, 0x69);
+        g_assert_cmpint(pbRecvBuffer[1], ==, 0x00);
+    }
+}
+
+static void test_invalid_update_buffer(void)
+{
+    VReader *reader = vreader_get_reader_by_id(0);
+
+    g_assert_nonnull(reader);
+
+    test_invalid_update_buffer_applet(reader, TEST_CCC);
+    test_invalid_update_buffer_applet(reader, TEST_PKI);
+    test_invalid_update_buffer_applet(reader, TEST_PKI_2);
+    test_invalid_update_buffer_applet(reader, TEST_PASSTHROUGH);
+    test_invalid_update_buffer_applet(reader, TEST_EMPTY);
+
+    vreader_free(reader); /* get by id ref */
+}
+
+static void test_invalid_sign(void)
+{
+    VReader *reader = vreader_get_reader_by_id(0);
+    VReaderStatus status;
+    int dwRecvLength = APDUBufSize;
+    uint8_t pbRecvBuffer[APDUBufSize];
+    uint8_t apdu[] = {
+        0x00, 0x42, 0x00, 0xff, 0x00
+    };
+    int apdu_len = 5;
+
+    g_assert_nonnull(reader);
+
+    select_applet(reader, TEST_PKI);
+
+    /* Sign/Decipher requires P2 = 0 */
+    status = vreader_xfr_bytes(reader,
+                               apdu, apdu_len,
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[0], ==, 0x6a);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x86);
+
+    /* Sign/Decipher requires P1 = 0x00 or 0x80 */
+    apdu[3] = 0xff;
+    apdu[4] = 0x00;
+    status = vreader_xfr_bytes(reader,
+                               apdu, apdu_len,
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[0], ==, 0x6a);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x86);
+
+    vreader_free(reader); /* get by id ref */
+}
+
+static void test_invalid_class(void)
+{
+    VReader *reader = vreader_get_reader_by_id(0);
+    VReaderStatus status;
+    int dwRecvLength = APDUBufSize;
+    uint8_t pbRecvBuffer[APDUBufSize];
+    uint8_t apdu[] = {
+        0xfe, 0x42, 0x00, 0xff, 0x00
+    };
+    int apdu_len = 5;
+
+    g_assert_nonnull(reader);
+
+    select_gp(reader);
+
+    /* Only ISO 7816 class(es) supported. Anything else should fail */
+    status = vreader_xfr_bytes(reader,
+                               apdu, apdu_len,
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[0], ==, 0x69);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x00);
+
+    /*  ISO 7816 PTS class is even more special -- it should just reply with the "APDU" sent */
+    apdu[0] = 0xff;
+    dwRecvLength = APDUBufSize;
+    status = vreader_xfr_bytes(reader,
+                               apdu, apdu_len,
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 5);
+    g_assert_cmpint(pbRecvBuffer[0], ==, 0xff);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x42);
+    g_assert_cmpint(pbRecvBuffer[2], ==, 0x00);
+    g_assert_cmpint(pbRecvBuffer[3], ==, 0xff);
+    g_assert_cmpint(pbRecvBuffer[4], ==, 0x00);
+
+    /* 0x0e should be unsupported secure messaging */
+    apdu[0] = 0x0e;
+    status = vreader_xfr_bytes(reader,
+                               apdu, apdu_len,
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[0], ==, 0x68);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x82);
+
+    vreader_free(reader); /* get by id ref */
+}
+
 static void test_invalid_acr(void)
 {
     VReader *reader = vreader_get_reader_by_id(0);
@@ -1037,6 +1249,16 @@ static void test_invalid_acr(void)
     g_assert_cmpint(pbRecvBuffer[0], ==, VCARD7816_SW1_COMMAND_ERROR);
     g_assert_cmpint(pbRecvBuffer[1], ==, 0x84);
 
+    /* Any other P1 is invalid */
+    apdu[2] = 0x42;
+    dwRecvLength = APDUBufSize;
+    status = vreader_xfr_bytes(reader,
+                               apdu, 6,
+                               pbRecvBuffer, &dwRecvLength);
+    g_assert_cmpint(status, ==, VREADER_OK);
+    g_assert_cmpint(dwRecvLength, ==, 2);
+    g_assert_cmpint(pbRecvBuffer[0], ==, VCARD7816_SW1_COMMAND_ERROR);
+    g_assert_cmpint(pbRecvBuffer[1], ==, 0x00);
 
     vreader_free(reader); /* get by id ref */
 }
@@ -1122,6 +1344,7 @@ int main(int argc, char *argv[])
     g_test_add_func("/libcacard/xfer", test_xfer);
     g_test_add_func("/libcacard/select-coid", test_select_coid);
     g_test_add_func("/libcacard/cac-pki", test_cac_pki);
+    g_test_add_func("/libcacard/cac-pki-2", test_cac_pki_2);
     g_test_add_func("/libcacard/cac-ccc", test_cac_ccc);
     g_test_add_func("/libcacard/cac-aca", test_cac_aca);
     g_test_add_func("/libcacard/get-response", test_get_response);
@@ -1132,11 +1355,15 @@ int main(int argc, char *argv[])
     g_test_add_func("/libcacard/empty-applets", test_empty_applets);
     g_test_add_func("/libcacard/gp-applet", test_gp_applet);
     g_test_add_func("/libcacard/msft-applet", test_msft_applet);
+    g_test_add_func("/libcacard/invalid-apdu", test_invalid_apdu);
     g_test_add_func("/libcacard/invalid-properties-apdu", test_invalid_properties);
     g_test_add_func("/libcacard/invalid-select-apdu", test_invalid_select);
     g_test_add_func("/libcacard/invalid-instruction", test_invalid_instruction);
     g_test_add_func("/libcacard/invalid-read-buffer", test_invalid_read_buffer);
+    g_test_add_func("/libcacard/invalid-update-buffer", test_invalid_update_buffer);
+    g_test_add_func("/libcacard/invalid-sign", test_invalid_sign);
     g_test_add_func("/libcacard/invalid-acr", test_invalid_acr);
+    g_test_add_func("/libcacard/invalid-class", test_invalid_class);
     g_test_add_func("/libcacard/get-atr", test_atr);
     /* Even without the card, the passthrough applets are present */
     g_test_add_func("/libcacard/passthrough-applet", test_passthrough_applet);
